@@ -4,7 +4,7 @@ options(
     setup=Bunch(
         name="stockpyle",
         packages=["stockpyle"],
-        version="0.0.2",
+        version="0.0.3",
         license="BSD",
         author="Matt Pizzimenti",
         author_email="mjpizz+stockpyle@gmail.com",
@@ -71,8 +71,8 @@ SQLAlchemy objects::
     persistent_obj = MySqlAlchemyBackedClass()
     store.put(persistent_obj)
 
-Note the ordering in the MultieStore declaration: the SQLAlchemyStore comes last, since it acts as the final persistence layer.
-Subsequent gets will attempt process memory, then attempt memcache, and finally check the database.
+Note the ordering in the MultiStore declaration: the SqlAlchemyStore comes last, since it acts as the final persistence layer.
+Subsequent 'get' requests will attempt process memory, then attempt memcache, and finally check the database.
 
 Also, we can treat the process memory cache and the memcached differently by using different expirations.
 For example, you may want process memory to expire quickly, but memcached to last a little longer since
@@ -82,7 +82,7 @@ forces Foo objects to be expired more aggressively from the local memory than me
     pm = ProcessMemoryStore()
     mc = MemcacheStore(servers=["localhost:11711"])
     sa = SqlAlchemyStore()
-    store = MultiStore([pm, mc])
+    store = MultiStore([pm, mc, sa])
     
     # Foo objects will last 60 seconds in local memory, and 5 minutes in memcache
     pm.configure(classes=[Foo], lifetime=60)
@@ -107,39 +107,6 @@ Deleting objects is easy (batch deletes coming soon)::
 
     store.delete(obj1)
 
-You can use the Storable helper class to get class-level access to the storage APIs::
-
-    from stockpyle import Storable
-    
-    
-    class Bar(Storable):
-        
-        __stockpyle_keys__ = [("foo", "bar")]
-        
-        def __init__(self, foo, bar):
-            self.foo = foo
-            self.bar = bar
-    
-    
-    # bind to a storage object
-    store = ProcessMemoryStore()
-    Bar.bind_store(store)
-    
-    # save an object
-    obj = Bar(111, 777)
-    obj.put()
-    
-    # get an object
-    obj = Bar.get({"foo", "bar"})
-    
-    # delete an object
-    obj.delete()
-    
-    # batched get
-    obj1, obj2 = Bar.batched_get([
-        {"foo": 111, "bar": 777},
-        {"foo": 222, "bar": 888},
-        ])
 ''',
         zip_safe = False,
         )
