@@ -14,36 +14,36 @@ import stockpyle.stores as stores
 
 __all__  = [
     "stores",
-    "Storable",
+    # "Storable",
     ]
 
 
-class Storable(object):
-    
-    _store = None
-    
-    @classmethod
-    def bind_store(cls, store):
-        if cls._store:
-            raise StandardError("cannot bind object more than once")
-        else:
-            cls._store = store
-    
-    @classmethod
-    def unbind_store(cls):
-        cls._store = None
-    
-    def put(self):
-        self.__class__._store.put(self)
-    
-    def delete(self):
-        self.__class__._store.delete(self)
-    
-    @classmethod
-    def get(cls, key):
-        return cls._store.get(cls, key)
-    
-    @classmethod
-    def batch_get(cls, keys):
-        return cls._store.batch_get(cls, keys)
-    
+# class Storable(object):
+#     
+#     _store = None
+#     
+#     @classmethod
+#     def bind_store(cls, store):
+#         if cls._store:
+#             raise StandardError("cannot bind object more than once")
+#         else:
+#             cls._store = store
+#     
+#     @classmethod
+#     def unbind_store(cls):
+#         cls._store = None
+#     
+#     def put(self):
+#         self.__class__._store.put(self)
+#     
+#     def delete(self):
+#         self.__class__._store.delete(self)
+#     
+#     @classmethod
+#     def get(cls, key):
+#         return cls._store.get(cls, key)
+#     
+#     @classmethod
+#     def batch_get(cls, keys):
+#         return cls._store.batch_get(cls, keys)
+#     
